#!/bin/bash
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://www.megamario.de/
# last revised       : 04.11.2007

softname='megamario'
softversion='1.5'
packageversion='50.2'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/MegaMario_v1.5_w32_linux.zip"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $src
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Super Mario Bros. 1 clone
$softname: 
$softname: It features everything the original features - with better 
$softname: graphics, higher resolution, smoother movement and new levels.
$softname: The story of mario and Luigi continues  in old-school style.
$softname: 
$softname: Mega Mario is written in C++ using SDL.
$softname: 
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
unzip $srcpkg -d $src
cd $src

# build
sed -i -e 's/-O2/-O2 -march=i486 -mtune=i686/' Makefile

    make PREFIX=/usr || return 1
    make install PREFIX=$dest/usr   

# add 'default' files
    cp -a \
      *.txt *.url editor_FAQ.PNG \
      $dest/usr/doc/$softname-$softversion
      
# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop 
[Desktop Entry]
Encoding=UTF-8
Name=MegaMario
Name[fr]=MegaMario
Comment=Mario Bros clone
Comment[fr]=Clone de Mario Bros
Exec=megamario
Icon=megamario
Categories=Game;ArcadeGame;
Terminal=false
Type=Application
EOF

# Make the package freedesktop compliant
cp $buildir/$softname.png $dest/usr/share/icons/hicolor/48x48/apps/

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# fix perm to let kids enter their highscores
chmod a+w $dest/usr/share/megamario/save.sav

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
